Context

Struct Context 

pub struct Context {
    pub context: Vec<String>,
    pub span: Span,
    pub label: Option<String>,
    pub span_indent: usize,
}
Context for a diagnostic.

Fields

context: Vec<String>

The context for the diagnostic, sequential lines of the source where the last string is the relevant line for the diagnostic. Each line is at most 100 characters wide

span: Span

The span of the context relevant to the diagnostic.

label: Option<String>

The label for the span.

span_indent: usize

How indented into the context the span starts.

Implementations

Source

impl Context

pub fn new(source: &str, span: Span) -> Self

Create the context for a diagnostic from a span and the source file.

pub fn label<S: ToString>(self, label: S) -> Self

Sets the label of the context.